local addonName, L = ...;
local BH = ByeHakmud

ByeHakmud_SavedVariables = false

SavedVariablesPerCharacter = false

BH.Vars = {}
BH.Vars.loaded = false;
BH.Vars.sv = {}
BH.Vars.svpc = {}

function BH.Vars:SetSavedVariables(vars)
    SavedVariables = vars
    self.sv = vars
end

function BH.Vars:SetSavedVariablesPerCharacter(vars)
    SavedVariablesPerCharacter = vars
    self.svpc = vars
end

function BH.Vars:GetPresets()
    if not self.sv.presets then
      self.sv.presets = {}
    end
    return self.sv.presets
end

function BH.Vars:PresetExists(preset)
    return self:GetPresets()[preset] ~= nil
end

function BH.Vars:CreatePreset(preset)
    return self:GetPreset(preset)
end

function BH.Vars:GetPreset(preset)
    local ps = self:GetPresets()
    if ps[preset] == nil then
	ps[preset] = {}
    end
    return ps[preset]
end

function BH.Vars:DeletePreset(preset)
    if preset then
      self:GetPresets()[preset] = nil
    end
end

function BH.Vars:GetEditorPresetName()
    return self.editorPresetName
end

function BH.Vars:SetEditorPresetName(presetName)
--    print("EditorPreset: "..tostring(presetName))
    self.editorPresetName = presetName
end

function BH.Vars:GetValue(valueName, defaultValue, presetName)
    local retVal = defaultValue;
    local psName = presetName or self:GetEditorPresetName()
    if self:PresetExists(psName) then
      local ps = self:GetPreset(psName)
      if ps[valueName] ~= nil then
	retVal = ps[valueName]
      end
    end
    return retVal;
end

function BH.Vars:SetValue(valueName, newValue, presetName)
    local psName = presetName or self:GetEditorPresetName()
--    print("SetValue "..tostring(psName).."["..tostring(valueName).."] := ("..tostring(newValue)..")")
    if psName then
      self:GetPreset(psName)[valueName] = newValue;
    end
end

function BH.Vars:IsHakmudKeptOnShift(presetName)
    return self:GetValue("HakmudKeptOnShift", true, presetName)
end

function BH.Vars:SetHakmudKeptOnShift(keep, presetName)
    self:SetValue("HakmudKeptOnShift", keep, presetName)
end

function BH.Vars:IsOnlyEjectWhenInParty(presetName)
    return self:GetValue("OnlyEjectWhenInParty", false, presetName)
end

function BH.Vars:SetOnlyEjectWhenInParty(ejectInParty, presetName)
    self:SetValue("OnlyEjectWhenInParty", ejectInParty, presetName)
end

function BH.Vars:GetChannelToNotify(presetName)
    return self:GetValue("ChannelToNotify", "local", presetName)
end

function BH.Vars:SetChannelToNotify(channel, presetName)
    self:SetValue("ChannelToNotify", channel, presetName)
end

function BH.Vars:GetNotifyMsg(presetName)
    local retVal = self:GetValue("NotifyMsg", nil, presetName)
    return retVal or TL("ByeHakmud ejected [passenger] from [mount]")
end

function BH.Vars:SetNotifyMsg(msg, presetName)
    self:SetValue("NotifyMsg", msg, presetName)
end

function BH.Vars:GetVersion()
	local version = "unversioned";
	local repoDate = "$Date: 2012-10-31 13:54:31 +0000 (Wed, 31 Oct 2012) $";
	local repoUrl = "$URL: file:///media/cf-repositories/svn/wow/byehakmud/mainline/tags/V%202.02.00/ByeHakmudVars.lua $";

	repoUrl = string.gsub(repoUrl, "%%20", " "); -- spaces are url encoded
	local tagPattern = "/tags/[^/]*";
	local tagStart, tagEnd = string.find(repoUrl, tagPattern);

	if (tagStart ~= nil and tagEnd ~= nil) then
		tagStart = tagStart + string.len("/tags/");
		version = string.sub(repoUrl, tagStart, tagEnd);
	else
		local datePattern = "$Date:[^$]*";
		local dateStart, dateEnd = string.find(repoDate, datePattern);
		if (dateStart ~= nil and dateEnd ~= nil) then
			dateStart = dateStart + string.len("$Date:");
			dateStr = string.sub(repoDate, dateStart, dateEnd);
			version = "unversioned "..tostring(dateStr);
		end
	end
	
	return version;
end 

function BH.Vars:GetAddonUrl()
    return "http://www.curse.com/addons/wow/byehakmud"
end

function BH.Vars:GetPlayerPermissions(presetName)
    local psName = presetName or self:GetEditorPresetName()
    retVal = self:GetValue("PlayerPermissions", nil, psName)
    if psName and retVal == nil then
      retVal = {}
      self:SetValue("PlayerPermissions", retVal, psName)
    end
    return retVal
end

function BH.Vars:GetMountIDToSeat(presetName)
    local psName = presetName or self:GetEditorPresetName()
    retVal = self:GetValue("MountIDToSeat", nil, psName)
    if psName and retVal == nil then
      retVal = {}
      self:SetValue("MountIDToSeat", retVal, psName)
    end
    return retVal
end

function BH.Vars:IsLoaded()
    return BH.Vars.loaded
end

function BH.Vars:IsUsedInWorld(presetName)
    return self:GetValue("UsedInWorld", true, presetName)
end

function BH.Vars:SetUsedInWorld(value, presetName)
    self:SetValue("UsedInWorld", value, presetName)
end

function BH.Vars:IsUsedInScenario(presetName)
    return self:GetValue("UsedInScenario", true, presetName)
end

function BH.Vars:SetUsedInScenario(value, presetName)
    self:SetValue("UsedInScenario", value, presetName)
end

function BH.Vars:IsUsedInDungeon(presetName)
    return self:GetValue("UsedInDungeon", true, presetName)
end

function BH.Vars:SetUsedInDungeon(value, presetName)
    self:SetValue("UsedInDungeon", value, presetName)
end

function BH.Vars:IsUsedInRaid(presetName)
    return self:GetValue("UsedInRaid", true, presetName)
end

function BH.Vars:SetUsedInRaid(value, presetName)
    self:SetValue("UsedInRaid", value, presetName)
end

function BH.Vars:IsUsedInArena(presetName)
    return self:GetValue("UsedInArena", true, presetName)
end

function BH.Vars:SetUsedInArena(value, presetName)
    self:SetValue("UsedInArena", value, presetName)
end
function BH.Vars:IsUsedInBattlegrounds(presetName)
    return self:GetValue("UsedInBattlegrounds", true, presetName)
end

function BH.Vars:SetUsedInBattlegrounds(value, presetName)
    self:SetValue("UsedInBattlegrounds", value, presetName)
end

function BH.Vars:IsUsedInRandomParty(presetName)
    return self:GetValue("UsedInRandomParty", true, presetName)
end

function BH.Vars:SetUsedInRandomParty(value, presetName)
    self:SetValue("UsedInRandomParty", value, presetName)
end

function BH.Vars:IsUsedInMixedParty(presetName)
    return self:GetValue("UsedInMixedParty", true, presetName)
end

function BH.Vars:SetUsedInMixedParty(value, presetName)
    self:SetValue("UsedInMixedParty", value, presetName)
end

function BH.Vars:IsUsedInGuildParty(presetName)
    return self:GetValue("UsedInGuildParty", true, presetName)
end

function BH.Vars:SetUsedInGuildParty(value, presetName)
    self:SetValue("UsedInGuildParty", value, presetName)
end

function BH.Vars:IsUsedInPvE(presetName)
    return self:GetValue("UsedInPvE", true, presetName)
end

function BH.Vars:SetUsedInPvE(value, presetName)
    self:SetValue("UsedInPvE", value, presetName)
end

function BH.Vars:IsUsedInPvP(presetName)
    return self:GetValue("UsedInPvP", true, presetName)
end

function BH.Vars:SetUsedInPvP(value, presetName)
    self:SetValue("UsedInPvP", value, presetName)
end
